@@ -3,7 +3,6 @@ Text-based visual representations of graphs
 """
 
 import sys
-import warnings
 from collections import defaultdict
 
 import networkx as nx
@@ -665,7 +664,7 @@ def _parse_network_text(lines):
         The graph corresponding to the lines in network text format.
     """
     from itertools import chain
-    from typing import Any, NamedTuple, Union
+    from typing import Any, NamedTuple
 
     class ParseStackFrame(NamedTuple):
         node: Any
